Coverage for test_cli.py: 0%

# Coverage for test_cli.py : 0%

## 5 statements 0 run 5 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 | # -*- coding: utf-8 -*- from jungle import cli def test_cli(runner): """Basic test""" result = runner.invoke(cli.cli) assert result.exit_code == 0 assert not result.exception